@@ -26,7 +26,7 @@ use constant DEFAULT_CACHE_TTL => 3600;
 use strict;
 use warnings;
 
-$VERSION = '0.37';
+$VERSION = '0.38';
 
 =pod
 
@@ -420,22 +420,31 @@ sub _get {
         )
     );
 
+    #
+    # untaint file
+    #
+    if ($file =~ /(.+)/) {
+        $file = $1;
+    }
+
     my $response = $self->ua->mirror($url, $file, $ttl);
 
     my $data = eval { decode_json(scalar(read_file($file))) };
 
-    if ($@) {
-        chomp($@);
+    if ($response->code >= 400) {
+        return $self->error_from_response($url, $response, $data);
+
+    } elsif ($data) {
+        return $self->rdap_from_response($url, $response, $data, %args);
+
+    } else {
+        unlink($file) if (-e $file);
+
         return $self->error(
             url         => $url,
             errorCode   => 500,
             title       => 'JSON parse error',
-            description => [ $@ ],
         );
-
-    } else {
-        return $self->rdap_from_response($url, $response, $data, %args);
-
     }
 }
 
